@@ -1,4 +1,4 @@
-# $Id: Order.pm 537 2005-06-22 23:43:02Z claco $
+# $Id: Order.pm 548 2005-06-25 02:10:13Z claco $
 package Handel::Order;
 use strict;
 use warnings;
@@ -33,7 +33,7 @@ __PACKAGE__->has_a(tax       => 'Handel::Currency');
 
 __PACKAGE__->add_constraint('id',       id       => \&constraint_uuid);
 __PACKAGE__->add_constraint('shopper',  shopper  => \&constraint_uuid);
-__PACKAGE__->add_constraint('type',     type     => \&constraint_cart_type);
+__PACKAGE__->add_constraint('type',     type     => \&constraint_order_type);
 __PACKAGE__->add_constraint('shipping', shipping => \&constraint_price);
 __PACKAGE__->add_constraint('handling', handling => \&constraint_price);
 __PACKAGE__->add_constraint('subtotal', subtotal => \&constraint_price);
